@@ -14,6 +14,8 @@ from requests.exceptions import ConnectionError
 from requests.packages.urllib3.exceptions import ProtocolError
 
 from .decorators import *
+from twarc.version import version, user_agent
+
 from requests_oauthlib import OAuth1, OAuth1Session, OAuth2Session
 from oauthlib.oauth2 import BackendApplicationClient
 
@@ -938,6 +940,9 @@ class Twarc(object):
             )
             self.client = oauth
 
+        if self.client:
+            self.client.headers.update({"User-Agent": user_agent})
+
     def get_keys(self):
         """
         Get the Twitter API keys. Order of precedence is command line,
